@@ -1,6 +1,6 @@
 """core.py
 
-The exception hook at the heart of Friendly-traceback.
+The exception hook at the heart of Friendly.
 
 You should not need to use any of the functions defined here;
 they are considered to be internal functions, subject to change at any
@@ -47,7 +47,7 @@ def convert_value_to_message(value):
     _ = current_lang.translate
     try:
         message = str(value)
-    except Exception:
+    except Exception:  # noqa
         message = STR_FAILED
     return message
 
@@ -123,15 +123,15 @@ class TracebackData:
             if value.text is not None:
                 self.bad_line = value.text  # typically includes "\n"
                 return
-            else:  # this can happen with editors_helpers.check_syntax()
-                try:
-                    self.bad_line = cache.get_source_lines(value.filename)[
-                        value.lineno - 1
-                    ]
-                except Exception:
-                    self.bad_line = "\n"
-                return
-        elif self.records:
+
+            # this can happen with editors_helpers.check_syntax()
+            try:
+                self.bad_line = cache.get_source_lines(value.filename)[value.lineno - 1]
+            except Exception:  # noqa
+                self.bad_line = "\n"
+            return
+
+        if self.records:
             self.exception_frame, self.filename, linenumber, _, _, _ = self.records[-1]
             _, line = cache.get_formatted_partial_source(
                 self.filename, linenumber, None
@@ -309,7 +309,7 @@ class FriendlyTraceback:
         except Exception as e:
             debug_helper.log("Uncaught exception in TracebackData.")
             debug_helper.log_error(e)
-            print("Internal problem in Friendly-traceback.")
+            print("Internal problem in Friendly.")
             print("Please report this issue.")
             raise SystemExit
         self.info = {"header": _("Python exception:")}
@@ -338,10 +338,7 @@ class FriendlyTraceback:
         self.assign_location()
         self.assign_cause()
         # removing null values
-        to_remove = []
-        for key in self.info:
-            if not self.info[key]:
-                to_remove.append(key)
+        to_remove = [key for key in self.info if not self.info[key]]
         for key in to_remove:
             del self.info[key]
 
@@ -361,7 +358,8 @@ class FriendlyTraceback:
         _ = current_lang.translate
         if self.tb_data.filename in ["<unknown>", "<string>"]:
             return
-        elif STR_FAILED in self.message:
+
+        if STR_FAILED in self.message:
             self.info["cause"] = _(
                 "Warning: improperly formed exception.\n"
                 "I suspect that a custom exception has been raised\n"
@@ -398,10 +396,6 @@ class FriendlyTraceback:
             etype, value, self.tb_data.exception_frame, self.tb_data
         )  # [3]
         self.info.update(**cause)
-        if "cause" in self.info:
-            self.info["cause_header"] = _(
-                "Likely cause based on the information given by Python:"
-            )
 
     def set_cause_syntax(self):
         """For SyntaxError and subclasses. Sets the value of the following
@@ -422,34 +416,23 @@ class FriendlyTraceback:
 
         if self.tb_data.filename == "<unknown>":
             return
-        elif self.tb_data.filename == "<stdin>":
+
+        if self.tb_data.filename == "<stdin>":
             self.info["cause"] = cannot_analyze_stdin()
             return
+
         if etype.__name__ == "IndentationError":
             self.info["cause"] = indentation_error.set_cause_indentation_error(
                 value, self.tb_data.statement
             )
             return
-        elif etype.__name__ == "TabError":
+
+        if etype.__name__ == "TabError":
             return
 
         cause = analyze_syntax.set_cause_syntax(value, self.tb_data)
         self.info.update(**cause)
 
-        if "cause" in self.info:
-            if "invalid syntax" in self.message:
-                if self.tb_data.filename == "<string>":
-                    return
-                else:
-                    self.info["cause_header"] = _(
-                        "Python's error message (invalid syntax) "
-                        "cannot be used to identify the problem:"
-                    )
-            else:
-                self.info["cause_header"] = _(
-                    "Likely cause based on the information given by Python:"
-                )
-
     def assign_generic(self):
         """Assigns the generic information about a given error. This is
         the answer to ``what()`` as in "What is a NameError?"
@@ -482,6 +465,7 @@ class FriendlyTraceback:
         if not records:
             debug_helper.log("No record in assign_location().")
             return
+
         self.locate_exception_raised(records[-1])
         if len(records) > 1:
             self.locate_last_call(records[0])
@@ -500,6 +484,7 @@ class FriendlyTraceback:
 
         frame, filename, linenumber, _func, lines, index = record
         if lines == ["\n"] and source_cache.idle_get_lines is not None:
+            # skipcq: PYL-E1102
             lines = source_cache.idle_get_lines(filename, linenumber - 1)
 
         partial_source = get_partial_source(
@@ -546,6 +531,7 @@ class FriendlyTraceback:
 
         frame, filename, linenumber, _func, lines, index = record
         if lines == ["\n"] and source_cache.idle_get_lines is not None:
+            # skipcq: PYL-E1102
             lines = source_cache.idle_get_lines(filename, linenumber - 1)
         partial_source = get_partial_source(filename, linenumber, lines, index)
         filename = path_utils.shorten_path(filename)
@@ -631,11 +617,7 @@ class FriendlyTraceback:
         python_tb = [line.rstrip() for line in self.tb_data.formatted_tb]
 
         tb = self.create_traceback()
-        if len(tb) > 10:
-            shortened_tb = tb[0:2] + suppressed + tb[-6:]
-        else:
-            shortened_tb = tb[:]
-
+        shortened_tb = tb[0:2] + suppressed + tb[-7:] if len(tb) > 10 else tb[:]
         pattern = re.compile(r'File "(.*)", ')
         temp = []
         for line in shortened_tb:
@@ -658,11 +640,7 @@ class FriendlyTraceback:
             for line in python_tb:  # excluding our own code
                 if exclude and line.strip() == "exec(code, self.locals)":
                     continue
-                exclude = False
-                for filename in EXCLUDED_FILE_PATH:
-                    if filename in line:
-                        exclude = True
-                        break
+                exclude = any(filename in line for filename in EXCLUDED_FILE_PATH)
                 if exclude:
                     continue
                 tb.append(line)
@@ -682,6 +660,7 @@ class FriendlyTraceback:
         )
         # The following is needed for some determining the cause in at
         # least one case.
+        # skipcq: PYL-W0201
         self.tb_data.simulated_python_traceback = "\n".join(tb) + "\n"
 
     @staticmethod
@@ -748,7 +727,7 @@ class FriendlyTraceback:
             if _line is None:
                 try:
                     _line = lines[value.lineno - 1]
-                except Exception:
+                except Exception:  # noqa
                     pass
             if _line is not None:
                 if filename == "<fstring>" and lines == ["\n"]:
